==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/servicediscovery.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>DiscoInfoWindow</name>
    <message>
        <source>Error %1: %2</source>
        <translation>Ошибка %1: %2</translation>
    </message>
    <message>
        <source>Discovery Info - %1</source>
        <translation>Обзорная информация - %1</translation>
    </message>
</context>
<context>
    <name>DiscoInfoWindowClass</name>
    <message>
        <source>Identities:</source>
        <translation>Элементы:</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Категория</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Features:</source>
        <translation>Возможности:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Расширения</translation>
    </message>
</context>
<context>
    <name>DiscoItemsModel</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Узел</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Identity:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Элемент:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;%1 (Category: &apos;%2&apos;; Type: &apos;%3&apos;)&lt;/li&gt;</source>
        <translation>&lt;li&gt;%1 (Категория: &apos;%2&apos;; Тип: &apos;%3&apos;)&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Features:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Возможности:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>true</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>false</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Error %1: %2</source>
        <translation>Ошибка %1: %2</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindow</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперёд</translation>
    </message>
    <message>
        <source>Discover</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Disco info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Add Contact</source>
        <translation>Добавить контакт</translation>
    </message>
    <message>
        <source>vCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Service Discovery - %1</source>
        <translation>Обзор сервисов - %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindowClass</name>
    <message>
        <source>Node:</source>
        <translation>Узел:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <source>Item:</source>
        <translation>Элемент:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Поиск:</translation>
    </message>
</context>
<context>
    <name>ServiceDiscovery</name>
    <message>
        <source>Service Discovery</source>
        <translation>Обзор сервисов</translation>
    </message>
    <message>
        <source>JID Escaping</source>
        <translation>Экранирование JID</translation>
    </message>
    <message>
        <source>Discovery Info</source>
        <translation>Обзорная информация</translation>
    </message>
    <message>
        <source>Entity Capabilities</source>
        <translation>Возможности объекта</translation>
    </message>
    <message>
        <source>Allows to receive information about Jabber entities</source>
        <translation>Позволяет получать информацию о джаббер сущностях</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information and items</source>
        <translation>Поддерживает обмен обзорной информацией и элементами</translation>
    </message>
    <message>
        <source>Discovery Information</source>
        <translation>Обзорная информация</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information</source>
        <translation>Поддерживает обмен обзорной информацией</translation>
    </message>
    <message>
        <source>Discovery Items</source>
        <translation>Обзорные элементы</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery items</source>
        <translation>Поддерживает обмен обзорными элементами</translation>
    </message>
    <message>
        <source>Publish Items</source>
        <translation>Публикация элементов</translation>
    </message>
    <message>
        <source>Supports the publishing of the discovery items</source>
        <translation>Поддерживает публикацию обзорных элементов</translation>
    </message>
    <message>
        <source>Supports the caching of the discovery information</source>
        <translation>Поддерживает кэширование обзорной информации</translation>
    </message>
    <message>
        <source>Supports the displaying of the jabber identifiers with disallowed characters</source>
        <translation>Поддерживает отображение джаббер идентификаторов с запрещёнными символами</translation>
    </message>
    <message>
        <source>Service discovery window</source>
        <translation>Окно обзора сервисов</translation>
    </message>
    <message>
        <source>Move back</source>
        <translation>Перейти назад</translation>
    </message>
    <message>
        <source>Move forward</source>
        <translation>Перейти вперед</translation>
    </message>
    <message>
        <source>Discover item</source>
        <translation>Обзор элемента</translation>
    </message>
    <message>
        <source>Reload items</source>
        <translation>Перезагрузить элементы</translation>
    </message>
    <message>
        <source>Show discovery info</source>
        <translation>Показать обзорную информацию</translation>
    </message>
    <message>
        <source>Add item to roster</source>
        <translation>Добавить элемент в список контактов</translation>
    </message>
    <message>
        <source>Show vCard</source>
        <translation>Показать vCard</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <comment>Show vCard</comment>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Close discovery window</source>
        <translation>Закрыть окно обзора сервисов</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close discovery window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Category: %1; Type: %2</source>
        <translation>Категория: %1; Тип: %2</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/ru/servicediscovery.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>DiscoInfoWindow</name>
    <message>
        <source>Discovery Info - %1</source>
        <translation>Обзорная информация - %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Ошибка: %1</translation>
    </message>
</context>
<context>
    <name>DiscoInfoWindowClass</name>
    <message>
        <source>Identities:</source>
        <translation>Элементы:</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Категория</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Features:</source>
        <translation>Возможности:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Расширения</translation>
    </message>
</context>
<context>
    <name>DiscoItemsModel</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Узел</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Identity:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Элемент:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;%1 (Category: &apos;%2&apos;; Type: &apos;%3&apos;)&lt;/li&gt;</source>
        <translation>&lt;li&gt;%1 (Категория: &apos;%2&apos;; Тип: &apos;%3&apos;)&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Features:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Возможности:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>true</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>false</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Ошибка: %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindow</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперёд</translation>
    </message>
    <message>
        <source>Discover</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Disco info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Add Contact</source>
        <translation>Добавить контакт</translation>
    </message>
    <message>
        <source>vCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Service Discovery - %1</source>
        <translation>Обзор сервисов - %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindowClass</name>
    <message>
        <source>Node:</source>
        <translation>Узел:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <source>Item:</source>
        <translation>Элемент:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Поиск:</translation>
    </message>
</context>
<context>
    <name>ServiceDiscovery</name>
    <message>
        <source>Service Discovery</source>
        <translation>Обзор сервисов</translation>
    </message>
    <message>
        <source>JID Escaping</source>
        <translation>Экранирование JID</translation>
    </message>
    <message>
        <source>Discovery Info</source>
        <translation>Обзорная информация</translation>
    </message>
    <message>
        <source>Entity Capabilities</source>
        <translation>Возможности объекта</translation>
    </message>
    <message>
        <source>Allows to receive information about Jabber entities</source>
        <translation>Позволяет получать информацию о джаббер сущностях</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information and items</source>
        <translation>Поддерживает обмен обзорной информацией и элементами</translation>
    </message>
    <message>
        <source>Discovery Information</source>
        <translation>Обзорная информация</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information</source>
        <translation>Поддерживает обмен обзорной информацией</translation>
    </message>
    <message>
        <source>Discovery Items</source>
        <translation>Обзорные элементы</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery items</source>
        <translation>Поддерживает обмен обзорными элементами</translation>
    </message>
    <message>
        <source>Publish Items</source>
        <translation>Публикация элементов</translation>
    </message>
    <message>
        <source>Supports the publishing of the discovery items</source>
        <translation>Поддерживает публикацию обзорных элементов</translation>
    </message>
    <message>
        <source>Supports the caching of the discovery information</source>
        <translation>Поддерживает кэширование обзорной информации</translation>
    </message>
    <message>
        <source>Supports the displaying of the jabber identifiers with disallowed characters</source>
        <translation>Поддерживает отображение джаббер идентификаторов с запрещёнными символами</translation>
    </message>
    <message>
        <source>Service discovery window</source>
        <translation>Окно обзора сервисов</translation>
    </message>
    <message>
        <source>Move back</source>
        <translation>Перейти назад</translation>
    </message>
    <message>
        <source>Move forward</source>
        <translation>Перейти вперед</translation>
    </message>
    <message>
        <source>Discover item</source>
        <translation>Обзор элемента</translation>
    </message>
    <message>
        <source>Reload items</source>
        <translation>Перезагрузить элементы</translation>
    </message>
    <message>
        <source>Show discovery info</source>
        <translation>Показать обзорную информацию</translation>
    </message>
    <message>
        <source>Add item to roster</source>
        <translation>Добавить элемент в список контактов</translation>
    </message>
    <message>
        <source>Show vCard</source>
        <translation>Показать vCard</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <comment>Show vCard</comment>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Close discovery window</source>
        <translation>Закрыть окно обзора сервисов</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close discovery window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Category: %1; Type: %2</source>
        <translation>Категория: %1; Тип: %2</translation>
    </message>
</context>
</TS>
